/* extend-fname.c: give a filename a suffix, if necessary.

Copyright (C) 1992, 93 Free Software Foundation, Inc.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#include "config.h"


string 
extend_filename (name, default_suffix)
     string name;
     string default_suffix;
{
  string new_s;
  string suffix = find_suffix (name);

  new_s = suffix == NULL 
          ? concat3 (name, ".", default_suffix) : name;
  return new_s;
}
