s/hash_prime=16319/hash_prime=4253/
s/hash_size=21000/hash_size=5000/
s/max_cites=3000/max_cites=750/
s/max_ent_ints=25000/max_ent_ints=3000/
s/max_ent_strs=10000/max_ent_strs=3000/
s/max_fields=69000/max_fields=17250/
s/max_strings=20000/max_strings=4000/
s/pool_size=512000/pool_size=120000/
